summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorSebastien Helleu <flashcode@flashtux.org>2010-02-11 10:12:25 +0100
committerSebastien Helleu <flashcode@flashtux.org>2010-02-11 10:12:25 +0100
commitbe8831499d856fe5e9aa601ec8050c91971daf83 (patch)
treefa296e93215e80b48ce4484cb49391a66f1dac9e
parent2e72679363832553172d3ea546aace64cd4f6881 (diff)
downloadweechat-be8831499d856fe5e9aa601ec8050c91971daf83.zip
Add missing IRC commands 276, 343
-rw-r--r--ChangeLog3
-rw-r--r--src/plugins/irc/irc-protocol.c13
2 files changed, 11 insertions, 5 deletions
diff --git a/ChangeLog b/ChangeLog
index ca22378e5..d8c00d539 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -1,7 +1,7 @@
WeeChat ChangeLog
=================
FlashCode <flashcode@flashtux.org>
-v0.3.2-dev, 2010-02-10
+v0.3.2-dev, 2010-02-11
Version 0.3.2 (under dev!)
@@ -31,6 +31,7 @@ Version 0.3.2 (under dev!)
in channel modes (bug #23961)
* irc: add option irc.look.item_nick_prefix
* irc: add command /map
+* irc: add missing commands 276, 343
* irc: fix compilation with old GnuTLS versions (bug #28723)
* logger: allow date format in logger options path and mask (task #9430)
* xfer: fix crash when purging old xfer chats (bug #28764)
diff --git a/src/plugins/irc/irc-protocol.c b/src/plugins/irc/irc-protocol.c
index c3f705c97..1d50076cf 100644
--- a/src/plugins/irc/irc-protocol.c
+++ b/src/plugins/irc/irc-protocol.c
@@ -2454,15 +2454,18 @@ irc_protocol_cmd_329 (struct t_irc_server *server, const char *command,
}
/*
* irc_protocol_cmd_330: '330' command (whois, logged in as)
*/
int
-irc_protocol_cmd_330 (struct t_irc_server *server, const char *command,
- int argc, char **argv, char **argv_eol)
+irc_protocol_cmd_330_343 (struct t_irc_server *server, const char *command,
+ int argc, char **argv, char **argv_eol)
{
/* 330 message looks like:
:server 330 mynick nick1 nick2 :is logged in as
+ 343 message looks like:
+ :server 343 mynick nick1 nick2 :is opered as
*/
IRC_PROTOCOL_MIN_ARGS(6);
@@ -3616,6 +3619,7 @@ irc_protocol_recv_command (struct t_irc_server *server, const char *entire_line,
{ "005", /* a server message */ 1, &irc_protocol_cmd_005 },
{ "221", /* user mode string */ 1, &irc_protocol_cmd_221 },
{ "275", /* whois (secure connection) */ 1, &irc_protocol_cmd_whois_nick_msg },
+ { "276", /* whois (has client certificate fingerprint) */ 1, &irc_protocol_cmd_whois_nick_msg },
{ "301", /* away message */ 1, &irc_protocol_cmd_301 },
{ "303", /* ison */ 1, &irc_protocol_cmd_303 },
{ "305", /* unaway */ 1, &irc_protocol_cmd_305 },
@@ -3639,13 +3643,14 @@ irc_protocol_recv_command (struct t_irc_server *server, const char *entire_line,
{ "327", /* whois (host) */ 1, &irc_protocol_cmd_327 },
{ "328", /* channel url */ 1, &irc_protocol_cmd_328 },
{ "329", /* channel creation date */ 1, &irc_protocol_cmd_329 },
- { "330", /* is logged in as */ 1, &irc_protocol_cmd_330 },
+ { "330", /* is logged in as */ 1, &irc_protocol_cmd_330_343 },
{ "331", /* no topic for channel */ 1, &irc_protocol_cmd_331 },
{ "332", /* topic of channel */ 0, &irc_protocol_cmd_332 },
{ "333", /* infos about topic (nick and date changed) */ 1, &irc_protocol_cmd_333 },
{ "335", /* is a bot on */ 1, &irc_protocol_cmd_whois_nick_msg },
{ "338", /* whois (host) */ 1, &irc_protocol_cmd_338 },
{ "341", /* inviting */ 1, &irc_protocol_cmd_341 },
+ { "343", /* is opered as */ 1, &irc_protocol_cmd_330_343 },
{ "344", /* channel reop */ 1, &irc_protocol_cmd_344 },
{ "345", /* end of channel reop list */ 1, &irc_protocol_cmd_345 },
{ "348", /* channel exception list */ 1, &irc_protocol_cmd_348 },
@@ -2454,15 +2454,18 @@ irc_protocol_cmd_329 (struct t_irc_server *server, const char *command,
}
/*
- * irc_protocol_cmd_330: '330' command (whois, logged in as)
+ * irc_protocol_cmd_330_343: '330' command (whois, is logged in as),
+ * '343' command (whois, is opered as)
*/
int